@@ -2,7 +2,7 @@
 import logging
 import os
 import sys
-import re
+import stat
 
 # external imports
 import confini
@@ -205,7 +205,7 @@ class Config(confini.Config):
         config.add(getattr(args, 'raw'), '_RAW')
 
         args_override = {}
-
+   
         if arg_flags & Flag.PROVIDER:
             args_override['RPC_PROVIDER'] = getattr(args, 'p')
             args_override['RPC_DIALECT'] = getattr(args, 'rpc_dialect')
@@ -213,10 +213,18 @@ class Config(confini.Config):
             args_override['CHAIN_SPEC'] = getattr(args, 'i')
         if arg_flags & Flag.KEY_FILE:
             args_override['WALLET_KEY_FILE'] = getattr(args, 'y')
-       
-        config.dict_override(args_override, 'cli args')
+            fp = getattr(args, 'passphrase_file')
+            if fp != None:
+                st = os.stat(fp)
+                if stat.S_IMODE(st.st_mode) & (stat.S_IRWXO | stat.S_IRWXG) > 0:
+                    logg.warning('others than owner have access on password file')
+                f = open(fp, 'r')
+                args_override['WALLET_PASSPHRASE'] = f.read()
+                f.close()
+            config.censor('PASSPHRASE', 'WALLET')
+        config.dict_override(args_override, 'cli args', allow_empty=True)
 
-        if arg_flags & Flag.PROVIDER:
+        if arg_flags & (Flag.PROVIDER | Flag.NO_TARGET) == Flag.PROVIDER:
             config.add(getattr(args, 'height'), '_HEIGHT')
         if arg_flags & Flag.UNSAFE:
             config.add(getattr(args, 'u'), '_UNSAFE')
